@@ -8,6 +8,8 @@
 #include <QApplication>
 #include <QTime>
 #include <QCryptographicHash>
+#include <QMutexLocker>
+
 
 extern "C" {
     #include "dlt_common.h"
@@ -77,7 +79,7 @@ bool DltFileIndexer::index(int num)
     if(!filterCache.isEmpty() && loadIndexCache(dltFile->getFileName(num)))
     {
         // loading index from filter is succesful
-        qDebug() << "Loaded index cache for file" << dltFile->getFileName(num);
+        //qDebug() << "Loaded index cache for file" << dltFile->getFileName(num);
         msecsIndexCounter = time.elapsed();
         return true;
     }
@@ -102,7 +104,7 @@ bool DltFileIndexer::index(int num)
     }
 
     // Initialise progress bar
-    emit(progressText(QString("%1/%2").arg(currentRun).arg(maxRun)));
+    emit(progressText(QString("Indexer %1/%2").arg(currentRun).arg(maxRun)));
     emit(progressMax(f.size()));
 
     // clear old index
@@ -112,6 +114,10 @@ bool DltFileIndexer::index(int num)
     char lastFound = 0;
     qint64 length;
     qint64 pos;
+    qint64 current_message_pos = 0;
+    qint64 next_message_pos = 0;
+    int counter_header = 0;
+    quint16 message_length = 0;
     char *data = new char[DLT_FILE_INDEXER_SEG_SIZE];
     do
     {
@@ -120,7 +126,23 @@ bool DltFileIndexer::index(int num)
         length = f.read(data,DLT_FILE_INDEXER_SEG_SIZE);
         for(int num=0;num < length;num++)
         {
-            if(data[num] == 'D')
+            if(counter_header>0)
+            {
+                counter_header++;
+                if (counter_header==16)
+                {
+                    // Read low byte of message length
+                    message_length = (unsigned char)data[num];
+                }
+                else if (counter_header==17)
+                {
+                    // Read high byte of message length
+                    counter_header = 0;
+                    message_length = (message_length<<8 | ((unsigned char)data[num])) +16;
+                    next_message_pos = current_message_pos + message_length;
+                }
+            }
+            else if(data[num] == 'D')
             {
                 lastFound = 'D';
             }
@@ -134,7 +156,13 @@ bool DltFileIndexer::index(int num)
             }
             else if(lastFound == 'T' && data[num] == 0x01)
             {
-                indexAllList.append(pos+num-3);
+                if( (next_message_pos == (pos+num-3)) || (next_message_pos == 0) )
+                {
+                    // Add message only when it is in the correct position in relationship to the last message or first message in file
+                    indexAllList.append(pos+num-3);
+                    current_message_pos = pos+num-3;
+                    counter_header = 1;
+                }
                 lastFound = 0;
             }
             else
@@ -166,10 +194,10 @@ bool DltFileIndexer::index(int num)
     msecsIndexCounter = time.elapsed();
 
     // write index if enabled
-    if(!filterCache.isEmpty())
+    if(false == filterCache.isEmpty())
     {
         saveIndexCache(dltFile->getFileName(num));
-        qDebug() << "Saved index cache for file" << dltFile->getFileName(num);
+        qDebug() << "Saved index cache for file" << dltFile->getFileName(num) << filterCache;
     }
 
     return true;
@@ -180,7 +208,7 @@ bool DltFileIndexer::indexFilter(QStringList filenames)
     QSharedPointer<QDltMsg> msg;
     QDltFilterList filterList;
     QTime time;
-
+    //qDebug() << "DltFileIndexer::indexFilter" << __FILE__ << __LINE__;
     // start performance counter
     time.start();
 
@@ -243,13 +271,18 @@ bool DltFileIndexer::indexFilter(QStringList filenames)
 
         // Update progress
         if(ix % 1000 == 0)
+        {
             emit(progress(ix));
+        }
 
         // stop if requested
         if(stopFlag)
         {
             if(useIndexerThread)
-                indexerThread.terminate();
+            {
+                indexerThread.requestStop();
+                indexerThread.wait();
+            }
 
             return false;
         }
@@ -262,7 +295,7 @@ bool DltFileIndexer::indexFilter(QStringList filenames)
         indexerThread.wait();
     }
 
-    qDebug() << "Created filter index for files" << filenames;
+    //qDebug() << "Created filter index for files" << filenames;
 
     // update performance counter
     msecsFilterCounter = time.elapsed();
@@ -275,7 +308,7 @@ bool DltFileIndexer::indexFilter(QStringList filenames)
     if(!filterCache.isEmpty())
     {
         saveFilterIndexCache(filterList, indexFilterList, filenames);
-        qDebug() << "Saved filter index cache for files" << filenames;
+        //qDebug() << "Saved filter index cache for files" << filenames;
     }
 
     return true;
@@ -329,13 +362,18 @@ bool DltFileIndexer::indexDefaultFilter()
 
         /* Update progress */
         if(ix % 1000 == 0)
+        {
             emit(progress(ix));
+        }
 
         /* stop if requested */
         if(stopFlag)
         {
             if(useDefaultFilterThread)
-                defaultFilterThread.terminate();
+            {
+                defaultFilterThread.requestStop();
+                defaultFilterThread.wait();
+            }
 
             return false;
         }
@@ -392,6 +430,10 @@ void DltFileIndexer::appendToGetLogInfoList(int value)
 
 void DltFileIndexer::run()
 {
+    //qDebug() << "DltFileIndexer::run" << __FILE__ << __LINE__;
+    // lock mutex while indexing
+    QMutexLocker scopedLock(&indexLock);
+
     // initialise stop flag
     stopFlag = false;
 
@@ -409,21 +451,24 @@ void DltFileIndexer::run()
         maxRun = dltFile->getNumberOfFiles()+1;
     else
         maxRun = 1;
+
     currentRun = 1;
 
     // index
     if(mode == modeIndexAndFilter)
     {
-        for(int num=0;num<dltFile->getNumberOfFiles();num++)
+        for(int num=0;num < dltFile->getNumberOfFiles();num++)
         {
             if(!index(num))
             {
-                // error
+                qDebug() << "Error in indexer" << __FILE__ << __LINE__;
                 return;
             }
+           // qDebug() << "setDLTIndex" << num << __FILE__ << __LINE__;
             dltFile->setDltIndex(indexAllList,num);
             currentRun++;
         }
+        //qDebug() << "emit(finishIndex());" << __FILE__ << __LINE__;
         emit(finishIndex());
     }
     else if(mode == modeNone)
@@ -443,6 +488,7 @@ void DltFileIndexer::run()
             // error
             return;
         }
+        dltFile->enableFilter(filtersEnabled);
         dltFile->setIndexFilter(indexFilterList);
         emit(finishFilter());
     }
@@ -450,7 +496,7 @@ void DltFileIndexer::run()
     // indexDefaultFilter
     if(mode == modeDefaultFilter)
     {
-        if(!indexDefaultFilter())
+        if(false == indexDefaultFilter())
         {
             // error
             return;
@@ -458,7 +504,9 @@ void DltFileIndexer::run()
         emit(finishDefaultFilter());
     }
 
+    //qDebug() << "Indexing done" << __FILE__ <<  __LINE__;
     // print performance counter
+    /*
     QTime time;
     time = QTime(0,0);time = time.addMSecs(msecsIndexCounter);
     qDebug() << "Duration Indexing:" << time.toString("hh:mm:ss.zzz") << "msecs";
@@ -466,18 +514,14 @@ void DltFileIndexer::run()
     qDebug() << "Duration Filter Indexing:" << time.toString("hh:mm:ss.zzz") << "msecs";
     time = QTime(0,0);time = time.addMSecs(msecsDefaultFilterCounter);
     qDebug() << "Duration Default Filter Indexing:" << time.toString("hh:mm:ss.zzz") << "msecs";
+    */
 }
 
 void DltFileIndexer::stop()
 {
     // stop the thread
     stopFlag = true;
-
-    while(isRunning())
-    {
-        // wait until task is not running anymore
-        usleep(100000);
-    }
+    wait();
 }
 
 // load/safe index from/to file
@@ -543,7 +587,7 @@ QString DltFileIndexer::filenameIndexCache(QString filename)
     // create filename
     filenameCache = QString(md5.toHex())+".dix";
 
-    qDebug() << filename << ">>" << filenameCache;
+    //qDebug() << filename << ">>" << filenameCache;
 
     return filenameCache;
 }
@@ -561,11 +605,15 @@ bool DltFileIndexer::loadFilterIndexCache(QDltFilterList &filterList, QVector<qi
     filenameCache = filenameFilterIndexCache(filterList,filenames);
 
     // load the cache file
-    if(!loadIndex(filterCache + "/" +filenameCache,index))
+    if(loadIndex(filterCache + "/" +filenameCache,index))
     {
-        // loading of cache file failed
-        return false;
+        qDebug() << "loadIndex" << filterCache + "/" +filenameCache << "success";
     }
+    else
+    {
+        qDebug() << "loadIndex" << filterCache + "/" +filenameCache << "failed";
+        return false;
+    }        
 
     return true;
 }
@@ -591,6 +639,29 @@ bool DltFileIndexer::saveFilterIndexCache(QDltFilterList &filterList, QVector<qi
     return true;
 }
 
+QByteArray DltFileIndexer::md5ActiveDecoderPlugins()
+{
+    QByteArray md5;
+    QString hashString = "Plugins";
+    QByteArray hashByteArray;
+
+    // walk through all active decoder plugins and generate String with all plugin names, version and loaded filename
+    for(int num=0;num<activeDecoderPlugins.size();num++)
+    {
+        QDltPlugin *plugin = activeDecoderPlugins[num];
+
+        hashString += plugin->getName();
+        hashString += plugin->getPluginVersion();
+        hashString += plugin->getFilename();
+    }
+    hashByteArray = hashString.toLatin1();
+
+    // calculate hash value
+    md5 = QCryptographicHash::hash(hashByteArray, QCryptographicHash::Md5);
+
+    return md5;
+}
+
 QString DltFileIndexer::filenameFilterIndexCache(QDltFilterList &filterList,QStringList filenames)
 {
     QString hashString;
@@ -615,12 +686,18 @@ QString DltFileIndexer::filenameFilterIndexCache(QDltFilterList &filterList,QStr
     md5 = QCryptographicHash::hash(hashByteArray, QCryptographicHash::Md5);
 
     // create filename
-    if(sortByTimeEnabled)
-        filename = QString(md5.toHex())+"_"+QString(md5FilterList.toHex())+"_S.dix";
-    else
-        filename = QString(md5.toHex())+"_"+QString(md5FilterList.toHex())+".dix";
+    filename = QString(md5.toHex()) + "_" + QString(md5FilterList.toHex());
+    if(this->pluginsEnabled)
+    {
+        filename += "_" + QString(md5ActiveDecoderPlugins().toHex());
+    }
+    if(this->sortByTimeEnabled)
+    {
+        filename += "_S";
+    }
+    filename += ".dix";
 
-    qDebug() << filenames << ">>" << filename;
+    //qDebug() << filenames << ">>" << filename;
 
     return filename;
 }
