@@ -9,8 +9,8 @@ class DltFileUtils : QObject
     Q_OBJECT
 public:
     DltFileUtils();
-    static QString createTempFile(QDir path);
-    static QDir getTempPath(SettingsDialog *settings);
+    static QString createTempFile(QDir path,  bool silentmode);
+    static QDir getTempPath(SettingsDialog *settings, bool silentmode);
 };
 
 #endif // DLTFILEUTILS_H
