@@ -24,6 +24,11 @@
 
 int main(int argc, char *argv[])
 {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
+    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
+
     QApplication a(argc, argv);
 
     QStringList arguments = a.arguments();
@@ -31,6 +36,16 @@ int main(int argc, char *argv[])
     opt->parse(&arguments);
 
     MainWindow w;
+    /* check variable commandline_finished
+       instead of stopping during constructor run
+       after running a commandline mode call
+       which often leads to crash
+    */
+    if(opt->getInstance()->isConvert() == true )
+    {
+        return 0;
+    }
+
     w.show();
 
     return a.exec();
