@@ -26,7 +26,10 @@
 #include <QShortcut>
 #include <QMessageBox>
 #include <QColor>
+#include <QComboBox>
 #include <QProgressBar>
+#include <QCompleter>
+#include <QStringListModel>
 
 #include "tablemodel.h"
 #include "project.h"
@@ -39,10 +42,9 @@
 #include "dltfileindexer.h"
 #include "workingdirectory.h"
 #include "exporterdialog.h"
-#include <QCompleter>
 #include "searchtablemodel.h"
 #include "ui_mainwindow.h"
-#include <QStringListModel>
+
 
 /**
  * When ecu items buffer size exceeds this while using
@@ -114,11 +116,9 @@ public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
-    QCompleter *newCompleter;
-
 private:
     Ui::MainWindow *ui;
-
+    QCompleter *newCompleter;
     /* Timer for connecting to ECUs */
     QTimer timer;
 
@@ -157,6 +157,7 @@ private:
     /* Settings dialog containing also the settings parameter itself */
     SettingsDialog *settings;
     QLineEdit *searchTextbox;
+    QComboBox *searchComboBox;
 
     /* injections */
     QString injectionAplicationId;
@@ -201,7 +202,20 @@ private:
     enum { MaxRecentHostnames = 10 };
     QStringList recentHostnames;
     enum { MaxRecentPorts = 10 };
-    QStringList recentPorts;
+    QStringList recentSerialPorts;
+    QStringList recentIPPorts;
+    QString recentEthIF;
+    QStringList recent_multicastAddresses;
+
+    /* for UDP live receive functions */
+    QHostAddress UDPsender; // in readdatagramm
+    quint16 senderPort; // in readdatagramm
+
+    /* used in ::read() */
+    QByteArray bufferHeader;
+    QByteArray bufferPayload;
+    QByteArray data;
+    QDltMsg qmsg;
 
     /* dlt-file Indexer with cancel cabability */
     DltFileIndexer *dltIndexer;
@@ -211,6 +225,17 @@ private:
 
     bool isSearchOngoing;
 
+    /* DLT File opened only Read only */
+    bool isDltFileReadOnly;
+
+    /* flag for enabled / disabled status of plugins */
+    bool pluginsEnabled;
+
+    /* keep the target version string submited by the target for internal use */
+    QString target_version_string;
+
+    QList<unsigned long int> selectedMarkerRows;
+
     /* functions called in constructor */
     void initState();
     void initView();
@@ -232,8 +257,8 @@ private:
 
     void reloadLogFileDefaultFilter();
 
-    void exportSelection(bool ascii,bool file);
-    void exportSelection_searchTable();
+    void exportSelection(bool ascii,bool file,bool payload_only);
+    void exportSelection_searchTable(bool payload_only);
 
     void ControlServiceRequest(EcuItem* ecuitem, int service_id );
     void SendInjection(EcuItem* ecuitem);
@@ -272,9 +297,12 @@ private:
     void updateIndex();
     void drawUpdatedView();
 
+     void syncCheckBoxesAndMenu();
+
     void updateRecentFileActions();
     void setCurrentFile(const QString &fileName);
     void removeCurrentFile(const QString &fileName);
+    void createsplitfile();
 
     void updateRecentProjectActions();
     void setCurrentProject(const QString &projectName);
@@ -285,11 +313,15 @@ private:
     void removeCurrentFilters(const QString &filtersName);
 
     void setCurrentHostname(const QString &hostName);
-    void setCurrentPort(const QString &portName);
+    void setCurrentMCAddress(const QString &mcastaddress);
+    void setCurrentSerialPort(const QString &portName);
+    void setCurrentIPPort(const QString &portName);
+    void setCurrentEthIF(const QString &EthIfName);
+    void setMcast(bool mcast);
+    void setInterfaceTypeSelection(int selectindex);
 
     void sendUpdates(EcuItem* ecuitem);
 
-    bool anyPluginsEnabled();
     bool anyFiltersEnabled();
 
     bool openDltFile(QStringList fileName);
@@ -297,13 +329,21 @@ private:
     bool openDlfFile(QString filename, bool replace);
 
     void commandLineConvertToASCII();
+    void commandLineConvertToDLT();
     void commandLineConvertToUTF8();
+    void commandLineConvertToCSV();
+    void commandLineConvertToDLTDecoded();
 
     void commandLineExecutePlugin(QString name, QString cmd, QStringList params);
 
     void iterateDecodersForMsg(QDltMsg &, int triggeredByUser);
 
-    QStringList getSerialPortsWithQextEnumerator();
+    /* return IP connection type as QString */
+    QString GetConnectionType(int iTypeNumber);
+
+    QStringList getAvailableSerialPorts();
+    QStringList getAvailableIPPorts() {return { "3490"};} // DLT standard port
+    QStringList getAvailableNetworkInterfaces();
 
     void deleteactualFile();
 
@@ -347,8 +387,9 @@ private slots:
     void reloadLogFileFinishIndex();
     void reloadLogFileFinishFilter();
     void reloadLogFileFinishDefaultFilter();
+    void triggerPluginsAutoload();
 
-    void on_tableView_selectionChanged(const QItemSelection & selected, const QItemSelection & deselected);
+    void onTableViewSelectionChanged(const QItemSelection & selected, const QItemSelection & deselected);
 
     void on_tableView_customContextMenuRequested(QPoint pos);
     void on_tableView_SearchIndex_customContextMenuRequested(QPoint pos);
@@ -379,12 +420,17 @@ private slots:
 
 public slots:
 
-    void on_New_triggered(QString fileName);
-    void on_Open_triggered(QStringList filenames);
-    void on_SaveAs_triggered(QString fileName);
+    void onNewTriggered(QString fileName);
+    void SplitTriggered(QString fileName);
+    void onOpenTriggered(QStringList filenames);
+    void onSaveAsTriggered(QString fileName);
     void on_action_menuFile_Clear_triggered();
     void on_action_menuFile_Quit_triggered();
-    void on_action_FindNext();
+    void on_actionFindNext();
+    void mark_unmark_lines();
+    void unmark_all_lines();
+
+
 private slots:
 
     // Search methods
@@ -418,8 +464,10 @@ private slots:
     void on_action_menuConfig_Disconnect_triggered();
     void on_action_menuConfig_Connect_triggered();
     void on_action_menuConfig_Delete_All_Contexts_triggered();
+    void onActionAenuConfigCopyPayloadToClipboardTriggered();
     void on_action_menuConfig_Copy_to_clipboard_triggered();
-    void on_action_menuConfig_SearchTable_Copy_to_clipboard_triggered();
+    void onActionMenuConfigSearchTableCopyToClipboardTriggered();
+    void onActionMenuConfigSearchTableCopyPayloadToClipboardTriggered();
 
     // DLT methods
     void on_action_menuDLT_Send_Injection_triggered();
@@ -468,8 +516,7 @@ private slots:
     void openRecentProject();
     void openRecentFilters();
     void applyConfigEnabled(bool enabled);
-    void tableViewValueChanged(int value);
-    void stateChangedTCP(QAbstractSocket::SocketState socketState);
+    void stateChangedIP(QAbstractSocket::SocketState socketState);
     void stateChangedSerial(bool dsrChanged);
     void sectionInTableDoubleClicked(int logicalIndex);
     void on_actionJump_To_triggered();
@@ -495,7 +542,6 @@ private slots:
 
     void on_actionMarker_triggered();
 
-    void on_actionApply_Configuration_triggered(bool checked);
     void on_actionToggle_PluginsEnabled_triggered(bool checked);
     void on_actionToggle_FiltersEnabled_triggered(bool checked);
     void on_actionToggle_SortByTimeEnabled_triggered(bool checked);
