@@ -27,6 +27,8 @@
 #include "dltsettingsmanager.h"
 #include "dltuiutils.h"
 #include "dlt_user.h"
+#include "optmanager.h"
+
 
 const char *loginfo[] = {"default","off","fatal","error","warn","info","debug","verbose","","","","","","","","",""};
 const char *traceinfo[] = {"default","off","on"};
@@ -36,12 +38,13 @@ EcuItem::EcuItem(QTreeWidgetItem *parent)
 , socket(0)
 {
     /* initialise receive buffer and message*/
-    id = "ECU";
+    id = default_id;
     description = "A new ECU";
     interfacetype = INTERFACETYPE_TCP; /* default TCP */
     hostname = "localhost";
+    mcastIP = "<none>";
     ipport = DLT_DAEMON_TCP_PORT;
-    baudrate = BAUD115200; /* default 115200 */
+    baudrate = QSerialPort::Baud115200; /* default 115200 */
     loglevel = DLT_LOG_INFO;
     tracestatus = DLT_TRACE_STATUS_OFF;
     verbosemode = 1;
@@ -55,13 +58,13 @@ EcuItem::EcuItem(QTreeWidgetItem *parent)
     sendGetSoftwareVersion = true;
     updateDataIfOnline = true;
     autoReconnect = true;
-    autoReconnectTimeout = 5;
-
+    autoReconnectTimeout = RECONNECT_TIMEOUT;
     totalBytesRcvd = 0;
     totalBytesRcvdLastTimeout = 0;
+    is_multicast = false;
 
-    tryToConnect = 0;
-    connected = 0;
+    tryToConnect = false;
+    connected = false;
 
     status = EcuItem::unknown;
 
@@ -81,22 +84,25 @@ EcuItem::~EcuItem()
 
 void EcuItem::update()
 {
-    if(tryToConnect & connected)
+    if( ( true == tryToConnect ) && ( true == connected ))
     {
         setData(0,Qt::DisplayRole,id + " online");
         setBackground(0,QBrush(QColor(Qt::green)));
+        //qDebug() << "green";
     }
-    else if(tryToConnect & !connected)
+    else if( ( true == tryToConnect )  && ( false == connected ))
     {
-        if(connectError.isEmpty())
+        if(true == connectError.isEmpty())
         {
             setData(0,Qt::DisplayRole,id + " connect");
             setBackground(0,QBrush(QColor(Qt::yellow)));
+            //qDebug() << "turn to yellow" << __LINE__ << __FILE__;
         }
         else
         {
             setData(0,Qt::DisplayRole,id + " connect ["+connectError+"]");
             setBackground(0,QBrush(QColor(Qt::red)));
+            //qDebug() << "red" << __LINE__ << __FILE__ <<  tryToConnect << connected;
         }
 
     }
@@ -109,11 +115,18 @@ void EcuItem::update()
     switch(interfacetype)
     {
         case EcuItem::INTERFACETYPE_TCP:
-            setData(1,Qt::DisplayRole,QString("%1 [%2:%3]").arg(description).arg(hostname).arg(ipport));
+            setData(1,Qt::DisplayRole,QString("%1 [TCP %2:%3]").arg(description).arg(hostname).arg(ipport));
             socket = & tcpsocket;
             break;
         case EcuItem::INTERFACETYPE_UDP:
-            setData(1,Qt::DisplayRole,QString("%1 [%2:%3]").arg(description).arg(hostname).arg(ipport));
+            if ( true == is_multicast)
+            {
+            setData(1,Qt::DisplayRole,QString("%1 [UDP (MC:%2) %3:%4]").arg(description).arg(mcastIP).arg(ethIF).arg(ipport));
+            }
+            else
+            {
+            setData(1,Qt::DisplayRole,QString("%1 [UDP %2:%3]").arg(description).arg(ethIF).arg(ipport));
+            }
             socket = & udpsocket;
             break;
         case EcuItem::INTERFACETYPE_SERIAL:
@@ -180,25 +193,27 @@ bool EcuItem::operator< ( const QTreeWidgetItem & other ) const {
     return currentItem.toLower() < otherItem.toLower();
 }
 
-bool EcuItem::isAutoReconnectTimeoutPassed(){
+bool EcuItem::isAutoReconnectTimeoutPassed()
+{
 
     bool timeoutPassed = false;
 
     QDateTime currentDateTime = QDateTime::currentDateTime();
 
-    //qDebug() << "currentDateTime:" << currentDateTime << " - nextTimeOut:" << autoReconnectTimestamp;
-
-    if(autoReconnectTimestamp <= currentDateTime){
+    if( autoReconnectTimestamp <= currentDateTime)
+    {
         timeoutPassed = true;
         autoReconnectTimestamp = currentDateTime.addSecs(autoReconnectTimeout);
+        //qDebug() << hostname << "currentDateTime:" << QDateTime::currentDateTime().toString("hh:mm:ss") << "next timeout:" << autoReconnectTimestamp.toString("hh:mm:ss") << autoReconnectTimestamp;// totalBytesRcvd - totalBytesRcvdLastTimeout;
     }
 
     return timeoutPassed;
 }
 
-void EcuItem::updateAutoReconnectTimestamp(){
-
+void EcuItem::updateAutoReconnectTimestamp()
+{
     autoReconnectTimestamp = QDateTime::currentDateTime().addSecs(autoReconnectTimeout);
+    //qDebug() << "updateAutoReconnectTimestamp" << autoReconnectTimestamp;
 }
 
 ApplicationItem::ApplicationItem(QTreeWidgetItem *parent)
@@ -303,6 +318,7 @@ FilterItem::FilterItem(QTreeWidgetItem *parent)
     filter.name = "New Filter";
 
     setCheckState(0,Qt::Checked);
+    filter.enableRegexp_Appid = false;
     filter.enableRegexp_Context = false;
     filter.enableRegexp_Header = false;
     filter.enableRegexp_Payload = false;
@@ -317,7 +333,7 @@ FilterItem::FilterItem(QTreeWidgetItem *parent)
     filter.enableCtrlMsgs = false;
     filter.enableMarker = false;
 
-    filter.filterColour = QColor();
+    filter.filterColour = "#000000";  // default constructor for QColor initialized at RGB 0,0,0
 
     filter.logLevelMax = 6;
     filter.logLevelMin = 0;
@@ -361,7 +377,8 @@ void FilterItem::update()
         break;
     }
 
-    if(filter.enableRegexp_Context || filter.enableRegexp_Header || filter.enableRegexp_Payload){
+    if(filter.enableRegexp_Appid || filter.enableRegexp_Context || filter.enableRegexp_Header || filter.enableRegexp_Payload)
+    {
         text += "RegExp";
     }
 
@@ -449,12 +466,13 @@ void FilterItem::update()
     }
     if(filter.isMarker())
     {
-        text += filter.filterColour.name();
+        QColor color(filter.filterColour);
+        text += color.name();
 
-        setBackground(0,filter.filterColour);
-        setBackground(1,filter.filterColour);
-        setForeground(0,DltUiUtils::optimalTextColor(filter.filterColour));
-        setForeground(1,DltUiUtils::optimalTextColor(filter.filterColour));
+        setBackground(0,color);
+        setBackground(1,color);
+        setForeground(0,DltUiUtils::optimalTextColor(color));
+        setForeground(1,DltUiUtils::optimalTextColor(color));
     }
 
     if(text.isEmpty()) {
@@ -551,12 +569,12 @@ void PluginItem::update()
             break;
     }
 
-    //setData(0,0,QString("%1 (%2:%3|%4 %5)").arg(this->getName()).arg(types.join("")).arg(*modeString).arg(list.size()).arg(this->getFilename()));
+    //qDebug() << this->getName() << *modeString << this->getFilename();
     setData(0,0,QString("%1").arg(plugin->getName()));
-    setData(1,0,QString("%1").arg(types.join("")));
-    setData(2,0,QString("%1").arg(*modeString));
-    setData(3,0,QString("%1").arg(list.size()));
-    setData(4,0,QString("%1").arg(this->getFilename()));
+    //setData(1,0,QString("%1").arg(types.join("")));
+    setData(1,0,QString("%1").arg(*modeString));
+    //setData(3,0,QString("%1").arg(list.size()));
+    setData(2,0,QString("%1").arg(this->getFilename()));
 
     delete modeString;
 }
@@ -641,7 +659,9 @@ bool Project::Load(QString filename)
     //plugin->clear();
 
     QXmlStreamReader xml(&file);
-    while (!xml.atEnd()) {
+
+    while (!xml.atEnd())
+    {
           xml.readNext();
 
           if(xml.isStartElement())
@@ -679,7 +699,7 @@ bool Project::Load(QString filename)
               {
                   settings->utcOffset = xml.readElementText().toLongLong();
               }
-              if(xml.name() == QString("utcOffset"))
+              if(xml.name() == QString("dst"))
               {
                   settings->dst = xml.readElementText().toInt();
               }
@@ -853,6 +873,17 @@ bool Project::Load(QString filename)
                     ecuitem->setHostname(xml.readElementText());
 
               }
+              if(xml.name() == QString("mcinterface"))
+              {
+                  if(ecuitem)
+                    ecuitem->setEthIF(xml.readElementText());
+
+              }
+              if(xml.name() == QString("mcIP"))
+              {
+                  if(ecuitem)
+                    ecuitem->setmcastIP(xml.readElementText());
+              }
               if(xml.name() == QString("ipport"))
               {
                   if(ecuitem)
@@ -869,7 +900,7 @@ bool Project::Load(QString filename)
               {
                   //TODO (BaudRateType)?
                   if(ecuitem)
-                      ecuitem->setBaudrate((BaudRateType)xml.readElementText().toInt());
+                      ecuitem->setBaudrate((QSerialPort::BaudRate)xml.readElementText().toInt());
 
               }
               if(xml.name() == QString("sendserialheadertcp"))
@@ -895,6 +926,12 @@ bool Project::Load(QString filename)
                   if(ecuitem)
                       ecuitem->setSyncSerialHeaderSerial(xml.readElementText().toInt());
 
+              }
+              if(xml.name() == QString("multicast"))
+              {
+                  if(ecuitem)
+                      ecuitem->is_multicast = xml.readElementText().toInt();
+
               }
               if(xml.name() == QString("autoReconnect"))
               {
@@ -1002,9 +1039,18 @@ bool Project::Load(QString filename)
               }
           }
     }
-    if (xml.hasError()) {
-        QMessageBox::warning(0, QString("XML Parser error"),
-                             xml.errorString());
+    if (xml.hasError())
+    {
+        if ( OptManager::getInstance()->issilentMode() == false )
+        {
+            QString xmlparsererror = QString("%1 in file\n%2\nLine: %3")
+                                .arg(xml.errorString())
+                                .arg(filename)
+                                .arg(xml.lineNumber());
+
+            QMessageBox::warning(0, "XML Parser error in project file !", xmlparsererror);
+        }
+        qDebug() << "XML parser error" << xml.errorString() << "in\n " << filename << "\nLine" << xml.lineNumber();
     }
 
     file.close();
@@ -1077,6 +1123,8 @@ bool Project::Save(QString filename)
         xml.writeTextElement("description",ecuitem->description);
         xml.writeTextElement("interface",QString("%1").arg(ecuitem->interfacetype));
         xml.writeTextElement("hostname",ecuitem->getHostname());
+        xml.writeTextElement("mcinterface",ecuitem->getEthIF());
+        xml.writeTextElement("mcIP",ecuitem->getmcastIP());
         xml.writeTextElement("ipport",QString("%1").arg(ecuitem->getIpport()));
         xml.writeTextElement("port",ecuitem->getPort());
         xml.writeTextElement("baudrate",QString("%1").arg(ecuitem->getBaudrate()));
@@ -1092,6 +1140,7 @@ bool Project::Save(QString filename)
         xml.writeTextElement("sendDefaultLogLevel",QString("%1").arg(ecuitem->sendDefaultLogLevel));
         xml.writeTextElement("sendGetSoftwareVersion",QString("%1").arg(ecuitem->sendGetSoftwareVersion));
         xml.writeTextElement("updatedata",QString("%1").arg(ecuitem->updateDataIfOnline));
+        xml.writeTextElement("multicast",QString("%1").arg(ecuitem->is_multicast));
         xml.writeTextElement("autoReconnect",QString("%1").arg(ecuitem->autoReconnect));
         xml.writeTextElement("autoReconnectTimeout",QString("%1").arg(ecuitem->autoReconnectTimeout));
 
@@ -1175,7 +1224,18 @@ bool Project::LoadFilter(QString filename, bool replace){
 
     QDltFilterList filterList;
 
-    filterList.LoadFilter(filename,replace);
+    if(!filterList.LoadFilter(filename,replace))
+    {
+        if ( OptManager::getInstance()->issilentMode() == false )
+        {
+        QMessageBox::critical(0, QString("DLT Viewer"),QString("Loading DLT Filter file failed!"));
+        }
+        else
+        {
+            qDebug() << "Loading" << filterList.getFilename() << " DLT Filter file failed !";
+        }
+    }
+
 
     if(replace)
         filter->clear();
