@@ -19,15 +19,29 @@
 
 #include <QSettings>
 #include <QFileDialog>
-#include <qmessagebox.h>
+#include <QMessageBox>
 #include <QDebug>
 #include <QFileInfo>
 #include <QDateTime>
+#include <QStandardPaths>
 
 #include "settingsdialog.h"
 #include "ui_settingsdialog.h"
 #include "version.h"
 #include "dltsettingsmanager.h"
+#include "dltuiutils.h"
+
+
+#if (WIN32)
+ #define TZSET _tzset()
+ #define TIMEZONE _timezone
+ #define DAYLIGHT _daylight
+#else
+ #define TZSET tzset()
+ #define TIMEZONE timezone
+ #define DAYLIGHT daylight
+#endif
+
 
 SettingsDialog::SettingsDialog(QDltFile *_qFile, QWidget *parent):
 
@@ -39,8 +53,7 @@ SettingsDialog::SettingsDialog(QDltFile *_qFile, QWidget *parent):
     //See man pages - tzset(3)
     //It is used to access DST and other timezone related information
     //and sets all timezone global variables
-    tzset();
-
+     TZSET;
     //timezone contains the difference in seconds between UTC and the local
     //standard time
     //qDebug()<< "Difference between UTC and the local standard time: "<<timezone<< " seconds."<<endl;
@@ -97,7 +110,7 @@ SettingsDialog::SettingsDialog(QDltFile *_qFile, QWidget *parent):
     ui->comboBoxUTCOffset->addItem("UTC+13:00",13*3600);
     ui->comboBoxUTCOffset->addItem("UTC+14:00",14*3600);
 
-    maxFileSizeMB = 0;
+    fmaxFileSizeMB = 0.0;
     appendDateTime = 0;
 }
 
@@ -139,7 +152,7 @@ void SettingsDialog::assertSettingsVersion()
        minor < QString(PACKAGE_MINOR_VERSION).toInt())
     {
         QString msg;
-        msg.append("Application version has changed. Settings might be incompatible.\n");
+        msg.append("The application version has changed ! The settings file config.ini might be incompatible.\n");
         msg.append("Would you like to remove all old settings and initialize new ones?\n");
         msg.append("Yes    - Reset settings to factory defaults.\n");
         msg.append("No     - Continue loading settings and risk crashing the application.\n");
@@ -191,7 +204,7 @@ void SettingsDialog::writeDlg()
     }
     // ^Else, uses default set in .ui
 
-    ui->lineEditSystemTemp->setText(QDir::tempPath());
+    ui->lineEditSystemTemp->setText(QStandardPaths::writableLocation(QStandardPaths::CacheLocation));
     ui->lineEditOwnTemp->setText(tempOwnPath);
     ui->checkBoxCloseWithoutAsking->setChecked(tempCloseWithoutAsking == 1 ? true : false);
     ui->checkBoxSaveOnClear->setChecked(tempSaveOnClear == 1 ? true : false);
@@ -216,27 +229,31 @@ void SettingsDialog::writeDlg()
     ui->checkBoxAutoMarkWarn->setCheckState(autoMarkWarn?Qt::Checked:Qt::Unchecked);
     ui->checkBoxAutoMarkMarker->setCheckState(autoMarkMarker?Qt::Checked:Qt::Unchecked);
     ui->checkBoxLoggingOnlyMode->setCheckState(loggingOnlyMode?Qt::Checked:Qt::Unchecked);
-    ui->groupBoxMaxFileSizeMB->setChecked(maxFileSizeMB);
-    ui->lineEditMaxFileSizeMB->setText(QString("%1").arg(maxFileSizeMB));
+    ui->groupBoxMaxFileSizeMB->setChecked(splitlogfile?Qt::Checked:Qt::Unchecked);
+    ui->lineEditMaxFileSizeMB->setText(QString("%1").arg(fmaxFileSizeMB));
     ui->checkBoxAppendDateTime->setCheckState(appendDateTime?Qt::Checked:Qt::Unchecked);
 
     /* table */
     ui->spinBoxFontSize->setValue(fontSize);
 
     /* Time settings */
-    ui->groupBoxAutomaticTimeSettings->setChecked(automaticTimeSettings?Qt::Checked:Qt::Unchecked);
-    if(ui->groupBoxAutomaticTimeSettings->isChecked()){
+    ui->groupBoxAutomaticTimeSettings->setChecked(automaticTimeSettings);
+    if(ui->groupBoxAutomaticTimeSettings->isChecked())
+    {
         ui->checkBoxDST->setEnabled(false);
         ui->comboBoxUTCOffset->setEnabled(false);
         ui->labelTimezone->setEnabled(false);
         ui->checkBoxAutomaticTimezone->setEnabled(false);
-    }else{
+    }
+    else
+    {
         ui->checkBoxDST->setEnabled(true);
         ui->comboBoxUTCOffset->setEnabled(true);
         ui->labelTimezone->setEnabled(true);
         ui->checkBoxAutomaticTimezone->setEnabled(true);
     }
-    ui->checkBoxAutomaticTimezone->setChecked(automaticTimezoneFromDlt?Qt::Checked:Qt::Unchecked);
+    ui->checkBoxAutomaticTimezone->setChecked(automaticTimezoneFromDlt);
+
     ui->checkBoxDST->setCheckState(dst?Qt::Checked:Qt::Unchecked);
     ui->comboBoxUTCOffset->setCurrentIndex(ui->comboBoxUTCOffset->findData(QVariant(utcOffset)));
 
@@ -247,15 +264,19 @@ void SettingsDialog::writeDlg()
 
     ui->checkBoxEcuid->setCheckState(showEcuId?Qt::Checked:Qt::Unchecked);
 
-    ui->groupBoxAppId->setChecked(showApId?Qt::Checked:Qt::Unchecked);
-    if(ui->groupBoxAppId->isChecked()){
+    ui->groupBoxAppId->setChecked(showApId);
+    if(ui->groupBoxAppId->isChecked())
+    {
         ui->radioButtonAppId->setEnabled(true);
         ui->radioButtonAppIdDesc->setEnabled(true);
-    }else{
+    }
+    else
+    {
         ui->radioButtonAppId->setEnabled(false);
         ui->radioButtonAppIdDesc->setEnabled(false);
     }
-    switch(showApIdDesc){
+    switch(showApIdDesc)
+    {
     case 0:
         ui->radioButtonAppId->setChecked(true);
         ui->radioButtonAppIdDesc->setChecked(false);
@@ -270,15 +291,19 @@ void SettingsDialog::writeDlg()
         break;
     }
 
-    ui->groupBoxConId->setChecked(showCtId?Qt::Checked:Qt::Unchecked);
-    if(ui->groupBoxConId->isChecked()){
+    ui->groupBoxConId->setChecked(showCtId);
+    if(ui->groupBoxConId->isChecked())
+    {
         ui->radioButtonConId->setEnabled(true);
         ui->radioButtonConIdDesc->setEnabled(true);
-    }else{
+    }
+    else
+    {
         ui->radioButtonConId->setEnabled(false);
         ui->radioButtonConIdDesc->setEnabled(false);
     }
-    switch(showCtIdDesc){
+    switch(showCtIdDesc)
+    {
     case 0:
         ui->radioButtonConId->setChecked(true);
         ui->radioButtonConIdDesc->setChecked(false);
@@ -293,15 +318,19 @@ void SettingsDialog::writeDlg()
         break;
     }
 
-    ui->groupBoxSessionId->setChecked(showSessionId?Qt::Checked:Qt::Unchecked);
-    if(ui->groupBoxSessionId->isChecked()){
+    ui->groupBoxSessionId->setChecked(showSessionId);
+    if(ui->groupBoxSessionId->isChecked())
+    {
         ui->radioButtonSessionId->setEnabled(true);
         ui->radioButtonSessionName->setEnabled(true);
-    }else{
+    }
+    else
+    {
         ui->radioButtonSessionId->setEnabled(false);
         ui->radioButtonSessionName->setEnabled(false);
     }
-    switch(showSessionName){
+    switch(showSessionName)
+    {
     case 0:
         ui->radioButtonSessionId->setChecked(true);
         ui->radioButtonSessionName->setChecked(false);
@@ -322,7 +351,7 @@ void SettingsDialog::writeDlg()
     ui->checkBoxMode->setCheckState(showMode?Qt::Checked:Qt::Unchecked);
     ui->checkBoxNoar->setCheckState(showNoar?Qt::Checked:Qt::Unchecked);
     ui->checkBoxPayload->setCheckState(showPayload?Qt::Checked:Qt::Unchecked);
-    ui->spinBox_showArguments->setValue(showArguments);
+   // ui->spinBox_showArguments->setValue(showArguments);
 
     /* other */
     ui->checkBoxWriteControl->setCheckState(writeControl?Qt::Checked:Qt::Unchecked);
@@ -369,10 +398,18 @@ void SettingsDialog::readDlg()
     autoMarkWarn = (ui->checkBoxAutoMarkWarn->checkState() == Qt::Checked);
     autoMarkMarker = (ui->checkBoxAutoMarkMarker->checkState() == Qt::Checked);
     loggingOnlyMode = (ui->checkBoxLoggingOnlyMode->checkState() == Qt::Checked);
-    if(ui->groupBoxMaxFileSizeMB->isChecked())
-        maxFileSizeMB = ui->lineEditMaxFileSizeMB->text().toInt();
-    else
-        maxFileSizeMB = 0;
+    splitlogfile = ui->groupBoxMaxFileSizeMB->isChecked();
+    if(splitlogfile != 0)
+     {
+        fmaxFileSizeMB = ui->lineEditMaxFileSizeMB->text().toFloat();
+        if (fmaxFileSizeMB < 0.01)
+        {
+          fmaxFileSizeMB = (float) 0.01;
+          qDebug() <<  "Caution: minimum split file size limited to 0.01 Mb !";
+          //QMessageBox::warning(0, QString("DLT Viewer"), QString("Minimum value limited to 0.01 Mb !"));
+        }
+     }
+
     appendDateTime = (ui->checkBoxAppendDateTime->checkState() == Qt::Checked);
 
     /* table */
@@ -402,7 +439,7 @@ void SettingsDialog::readDlg()
     showMode = ( ui->checkBoxMode->checkState() == Qt::Checked);
     showNoar = ( ui->checkBoxNoar->checkState() == Qt::Checked);
     showPayload = ( ui->checkBoxPayload->checkState() == Qt::Checked);
-    showArguments = (ui->spinBox_showArguments->value());
+   // showArguments = (ui->spinBox_showArguments->value());
 
     /* other */
     writeControl = (ui->checkBoxWriteControl->checkState() == Qt::Checked);
@@ -454,8 +491,10 @@ void SettingsDialog::writeSettings(QMainWindow *mainwindow)
     settings->setValue("startup/autoMarkWarn",autoMarkWarn);
     settings->setValue("startup/autoMarkMarker",autoMarkMarker);
     settings->setValue("startup/loggingOnlyMode",loggingOnlyMode);
-    settings->setValue("startup/maxFileSizeMB",maxFileSizeMB);
+    settings->setValue("startup/splitfileyesno",splitlogfile);
+    settings->setValue("startup/maxFileSizeMB",fmaxFileSizeMB);
     settings->setValue("startup/appendDateTime",appendDateTime);
+    settings->setValue("startup/markercolor",markercolor.name());
 
     /* table */
     settings->setValue("startup/fontSize",fontSize);
@@ -494,13 +533,13 @@ void SettingsDialog::writeSettings(QMainWindow *mainwindow)
     settings->setValue("startup/versionPatch", QString(PACKAGE_PATCH_LEVEL).toInt());
 }
 
+/* read the settings from config.ini */
 void SettingsDialog::readSettings()
 {
     DltSettingsManager *settings = DltSettingsManager::getInstance();
-
     /* Temp file */
     tempUseSystem               = settings->value("tempdir/tempUseSystem", 1).toInt();
-    tempSystemPath              = QDir::tempPath();
+    tempSystemPath              = QStandardPaths::writableLocation(QStandardPaths::CacheLocation);
     tempUseOwn                  = settings->value("tempdir/tempUseOwn", 0).toInt();
     tempOwnPath                 = settings->value("tempdir/tempOwnPath", QString("")).toString();
     tempCloseWithoutAsking      = settings->value("tempdir/tempCloseWithoutAsking", 0).toInt();
@@ -519,39 +558,49 @@ void SettingsDialog::readSettings()
     pluginsAutoloadPathName = settings->value("startup/pluginsAutoloadPathName",QString("")).toString();
     filterCache = settings->value("startup/filterCache",1).toInt();
     filterCacheDays = settings->value("startup/filterCacheDays",7).toInt();
-    filterCacheName = settings->value("startup/filterCacheName",QDir::tempPath()+"/dltviewer/cache").toString();
+    filterCacheName = settings->value("startup/filterCacheName",QStandardPaths::writableLocation(QStandardPaths::CacheLocation)+"/indexcache").toString();
     autoConnect = settings->value("startup/autoConnect",0).toInt();
     autoScroll = settings->value("startup/autoScroll",1).toInt();
     autoMarkFatalError = settings->value("startup/autoMarkFatalError",0).toInt();
     autoMarkWarn = settings->value("startup/autoMarkWarn",0).toInt();
     autoMarkMarker = settings->value("startup/autoMarkMarker",1).toInt();
     loggingOnlyMode = settings->value("startup/loggingOnlyMode",0).toInt();
-    maxFileSizeMB = settings->value("startup/maxFileSizeMB",0).toInt();
+    splitlogfile = settings->value("startup/splitfileyesno",0).toInt();
+    fmaxFileSizeMB = settings->value("startup/maxFileSizeMB",0).toFloat();
     appendDateTime = settings->value("startup/appendDateTime",0).toInt();
 
-    /* table */
+    markercolor.setNamedColor(settings->value("startup/markercolor","#aaaaaa").toString() );
+    QPalette palette = ui->labelSelectedMarkerColor->palette();
+    palette.setColor(QPalette::Active,this->backgroundRole(),markercolor);
+    ui->labelSelectedMarkerColor->setPalette(palette);
+
+
+    /* project table */
     fontSize = settings->value("startup/fontSize",8).toInt();
     automaticTimeSettings = settings->value("startup/automaticTimeSettings",1).toInt();
     automaticTimezoneFromDlt = settings->value("startup/automaticTimezoneFromDlt",1).toInt();
-    utcOffset = settings->value("startup/utcOffset",QVariant((qlonglong)timezone*-1)).toLongLong();
-    dst = settings->value("startup/dst",daylight == 0 ? 0 : 1).toInt();
+
+    utcOffset = settings->value("startup/utcOffset",QVariant((qlonglong)TIMEZONE * (-1) )).toLongLong();
+    dst = settings->value("startup/dst", DAYLIGHT == 0 ? 0 : 1).toInt();
+
     showIndex = settings->value("startup/showIndex",1).toInt();
     showTime = settings->value("startup/showTime",1).toInt();
     showTimestamp = settings->value("startup/showTimestamp",1).toInt();
-    showCount = settings->value("startup/showCount",1).toInt();
+    showCount = settings->value("startup/showCount",0).toInt();
 
     showEcuId = settings->value("startup/showEcuId",1).toInt();
     showApId = settings->value("startup/showApId",1).toInt();
     showApIdDesc = settings->value("startup/showApIdDesc",0).toInt();
     showCtId = settings->value("startup/showCtId",1).toInt();
     showCtIdDesc = settings->value("startup/showCtIdDesc",0).toInt();
-    showSessionId = settings->value("startup/showSessionId",1).toInt();
+    showSessionId = settings->value("startup/showSessionId",0).toInt();
     showSessionName = settings->value("startup/showSessionName",0).toInt();
     showType = settings->value("startup/showType",1).toInt();
 
-    showSubtype = settings->value("startup/showSubtype",1).toInt();
-    showMode = settings->value("startup/showMode",1).toInt();
-    showNoar = settings->value("startup/showNoar",1).toInt();
+    showSubtype = settings->value("startup/showSubtype",0).toInt();
+
+    showMode = settings->value("startup/showMode",0).toInt();
+    showNoar = settings->value("startup/showNoar",0).toInt();
     showPayload = settings->value("startup/showPayload",1).toInt();
     showArguments = settings->value("startup/showArguments",0).toInt();
 
@@ -563,16 +612,19 @@ void SettingsDialog::readSettings()
 
 
 
-QStringList SettingsDialog::getRecentFiles(){
+QStringList SettingsDialog::getRecentFiles()
+{
     return DltSettingsManager::getInstance()->value("other/recentFileList").toStringList();
 }
-QStringList SettingsDialog::getRecentProjects(){
+QStringList SettingsDialog::getRecentProjects()
+{
     return DltSettingsManager::getInstance()->value("other/recentProjectList").toStringList();
 }
 QStringList SettingsDialog::getRecentFilters(){
     return DltSettingsManager::getInstance()->value("other/recentFiltersList").toStringList();
 }
-QString SettingsDialog::getWorkingDirectory(){
+QString SettingsDialog::getWorkingDirectory()
+{
     return DltSettingsManager::getInstance()->value("work/workingDirectory",QDir::currentPath()).toString();
 }
 
@@ -636,9 +688,8 @@ void SettingsDialog::on_toolButtonDefaultFilterPath_clicked()
     workingDirectory = QFileInfo(fileName).absolutePath();
 
     ui->lineEditDefaultFilterPath->setText(fileName);
-
-    QMessageBox::warning(0, QString("DLT Viewer"),
-                         QString("Default filters will only be reloaded when triggered in the menu!"));
+    emit(FilterPathChanged());
+    //QMessageBox::warning(0, QString("DLT Viewer"), QString("Default filters will be reloaded at next program start !"));
 }
 
 void SettingsDialog::on_toolButtonTempPath_clicked()
@@ -719,12 +770,15 @@ void SettingsDialog::on_groupBoxAppId_clicked(bool checked)
 
 void SettingsDialog::on_groupBoxAutomaticTimeSettings_clicked(bool checked)
 {
-    if(checked){
+    if(checked)
+    {
         ui->checkBoxDST->setEnabled(false);
         ui->comboBoxUTCOffset->setEnabled(false);
         ui->labelTimezone->setEnabled(false);
         ui->checkBoxAutomaticTimezone->setEnabled(false);
-    }else{
+    }
+    else
+    {
         ui->checkBoxDST->setEnabled(true);
         ui->comboBoxUTCOffset->setEnabled(true);
         ui->labelTimezone->setEnabled(true);
@@ -752,8 +806,10 @@ void SettingsDialog::clearIndexCacheAfterDays()
     comparisonDate = comparisonDate.addSecs((quint64)filterCacheDays*-1*60*60*24);
 
     // check if index cache is enabled
-    if(!filterCache)
+    if(0 == filterCache)
+    {
         return;
+    }
 
     /* check if directory for configuration exists */
     QString path = filterCacheName;
@@ -787,26 +843,27 @@ void SettingsDialog::clearIndexCacheAfterDays()
     }
 }
 
-    void SettingsDialog::on_groupBoxArguments_clicked(bool checked)
+
+void SettingsDialog::on_checkBoxPluginsAutoload_stateChanged(int activated)
+{
+   if ( activated != 0)
     {
-        if (checked)
-        {
-          if (ui->spinBox_showArguments->value()<=0) ui->spinBox_showArguments->setValue(5); //set to default
-        }
-        else
-        {
-          ui->spinBox_showArguments->setValue(0);
-        }
+       emit(PluginsAutoloadChanged());
     }
 
-    void SettingsDialog::on_spinBox_showArguments_valueChanged(int i)
+}
+
+void SettingsDialog::on_pushButtonMarkerColor_clicked()
+{
+    QColor selectedcolor = QColorDialog::getColor( ui->labelSelectedMarkerColor->palette().background().color().name() );
+    QPalette palette = ui->labelSelectedMarkerColor->palette();
+    palette.setColor(QPalette::Active,this->backgroundRole(),selectedcolor);
+    palette.setColor(QPalette::Inactive,this->backgroundRole(),QColor(255,255,255,255));
+    palette.setColor(QPalette::Foreground,DltUiUtils::optimalTextColor(selectedcolor));
+    ui->labelSelectedMarkerColor->setPalette(palette);
+
+    if(selectedcolor.isValid())
     {
-     if (i<=0)
-     {
-      ui->groupBoxArguments->setChecked(false);
-     }
-     else
-     {
-         if (!ui->groupBoxArguments->isChecked()) ui->groupBoxArguments->setChecked(true);
-     }
+        this->markercolor =  selectedcolor;
     }
+}
